@@ -364,9 +364,15 @@ quick_box_size_request (GtkWidget        *widget,
 		max_size += spacing + arrow_height;
 		if (children == NULL) /* when the box is empty */
 			min_size = p->size / p->rows; 
-		requisition->width = MAX (p->size, arrow_width);
-		requisition->height = min_size;
-		p->size_hint[SIZE_HINT_MAX] = max_size - requisition->height;
+
+		/* FIXME: 
+		When the orientation is vertical, requisition->width expects the
+		height, and requisition->height expects the width. I don't know 
+		if this is by design or if it's a bug in gnome-panel, but 
+		swapping the width and the height works for now. */
+		requisition->height = MAX (p->size, arrow_width);
+		requisition->width = min_size;
+		p->size_hint[SIZE_HINT_MAX] = max_size - requisition->width;
 	}
 
 	p->size_hint[SIZE_HINT_MIN] = 0;
@@ -548,8 +554,7 @@ get_child_size (QuickBox *quick_box)
 	    (quick_box->priv->rows == 1))
 		return quick_box->priv->size;
 
-	child_size = quick_box->priv->size / quick_box->priv->rows;
-	child_size -= (quick_box->priv->rows - 1) * ICON_SPACING;
+	child_size = (quick_box->priv->size - (quick_box->priv->rows - 1) * ICON_SPACING) / quick_box->priv->rows;
 
 	return MAX (0, child_size);
 }
@@ -783,7 +788,7 @@ quick_box_size_allocate (GtkWidget        *widget,
 						child_requisition.width);
 	else
 		widget->allocation.height = MAX (widget->allocation.height, 
-						 child_requisition.height);
+						 child_requisition.width);
 
 	g_list_free (children);
 }
