@@ -22,6 +22,7 @@
 
 #include <config.h>
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 #include <libgnome/libgnome.h>
@@ -69,8 +70,6 @@ enum {
 static GtkTargetEntry target_table[] = {
 	{ "text/uri-list", 0, 0 }
 };
-static guint n_targets = sizeof (target_table) / sizeof (target_table[0]);
-
 
 static void
 destroy_prop_dlg_cb (GtkWidget   *widget, 
@@ -94,8 +93,12 @@ properties_verb_cb (BonoboUIComponent *uic,
 				  quick_lounge);
 	}
 
-	if (quick_lounge->prop_dialog != NULL)
+	if (quick_lounge->prop_dialog != NULL) {
+                gtk_window_set_screen (GTK_WINDOW (quick_lounge->prop_dialog),
+                                       gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+
 		gtk_window_present (GTK_WINDOW (quick_lounge->prop_dialog));
+        }
 }
 
 
@@ -129,8 +132,7 @@ about_verb_cb (BonoboUIComponent *uic,
 	       QuickLounge       *quick_lounge,
 	       const gchar       *verbname)
 {
-	GdkPixbuf  *pixbuf = NULL;
-        char       *file;
+        static GtkWidget *about_dialog = NULL;
 	const char *authors[] = {
 		"Paolo Bacchilega <paolo.bacchilega@libero.it>",
 		NULL
@@ -140,29 +142,34 @@ about_verb_cb (BonoboUIComponent *uic,
 		NULL
 	};
 	const char *translator_credits = _("translator_credits");
-	
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "quick-lounge-applet.png", TRUE, NULL);
-	if (file != NULL) {
-		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
-		g_free(file);
-	}
 
-	gtk_show_about_dialog (NULL,
-			       "name", _("Launchers List"),
-			       "version", VERSION,
-			       "copyright", "Copyright \xc2\xa9 2002-2004 Free Software Foundation, Inc.",
-			       "comments", _("Organize your favorite applications on the Panel"),
-			       "authors", authors,
-			       "documenters", documenters,
-			       "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-			       "logo", pixbuf,
-			       NULL);
+        if (about_dialog) {
+                gtk_window_set_screen (GTK_WINDOW (about_dialog),
+                                       gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+                gtk_window_present (GTK_WINDOW (about_dialog));
+                return;
+        }
+
+        about_dialog = gtk_about_dialog_new ();
+
+        g_object_set (about_dialog,	
+		      "name", _("Launchers List"),
+	              "version", VERSION,
+		      "copyright", "Copyright \xc2\xa9 2002-2008 Free Software Foundation, Inc.",
+	              "comments", _("Organize your favorite applications on the Panel"),
+	              "authors", authors,
+	              "documenters", documenters,
+    	              "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+	              "logo-icon-name", "quick-lounge-applet",
+	              NULL);
+
+	gtk_window_set_wmclass (GTK_WINDOW (about_dialog), "quick-lounge-applet", "Quick-lounge-applet"); 
+        gtk_window_set_screen (GTK_WINDOW (about_dialog), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+	g_signal_connect (about_dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &about_dialog);
+	g_signal_connect (about_dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+        gtk_widget_show (about_dialog);
 
-	if (pixbuf)
-		g_object_unref (pixbuf);
 }
-
-
 static const BonoboUIVerb menu_verbs [] = {
 	BONOBO_UI_UNSAFE_VERB ("QLProperties",   properties_verb_cb),
 	BONOBO_UI_UNSAFE_VERB ("QLHelp",         help_verb_cb),
@@ -406,8 +413,26 @@ ditem_properties_clicked (GtkWidget *w,
 	GtkWidget *dialog = data;
 
         if (response == GTK_RESPONSE_HELP) {
-		/* FIXME */
+		GError *error = NULL;
+		
+		gnome_help_display_desktop_on_screen (NULL,
+						      "user-guide",
+                                                      "user-guide.xml",
+                                                      "gospanel-52",
+                                                      gtk_window_get_screen (GTK_WINDOW (dialog)),
+                                                      &error);
 
+                if (error) {
+                        GtkWidget *message_dialog;
+                        message_dialog = gtk_message_dialog_new (NULL, 0,
+                                                                 GTK_MESSAGE_ERROR,
+                                                                 GTK_BUTTONS_OK,
+                                                                 _("There was an error displaying help: %s"),
+                                                                 error->message);
+                        g_error_free (error);
+                        gtk_dialog_run (GTK_DIALOG (message_dialog));
+                        gtk_widget_destroy (message_dialog);
+		}
 	} else if (response == REVERT_BUTTON) { 
 		QuickButton      *button;
 		GnomeDItemEdit   *dedit;
@@ -524,7 +549,7 @@ quick_lounge_util__item_properties (QuickLounge *quick_lounge,
 					      GTK_STOCK_HELP,
 					      GTK_RESPONSE_HELP,
 					      NULL);
-	gnome_window_icon_set_from_file (GTK_WINDOW (widget), GNOME_ICONDIR "quick-lounge-applet.png");
+	gtk_window_set_icon_name (GTK_WINDOW (widget), "quick-lounge-applet");
 	gtk_window_set_screen (GTK_WINDOW (widget), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
 
 	dialog = GTK_DIALOG (widget);
@@ -619,17 +644,25 @@ static int
 get_child_position (QuickBox  *quick_box,
 		    GtkWidget *widget)
 {
-	GList  *scan;
-	int     pos = 0;
+	GList    *children, *scan;
+	gboolean  found = FALSE;
+	int       pos;
 
-	for (scan = GTK_BOX (quick_box)->children; scan; scan = scan->next) {
-		GtkBoxChild *child = scan->data;
-
-		if (child->widget == widget)
-			return pos;
+	children = gtk_container_get_children (GTK_CONTAINER (quick_box));
+	for (pos = 0, scan = children; scan; pos++, scan = scan->next) {
+		GtkWidget *child_widget = scan->data;
+		if (child_widget == widget) {
+			found = TRUE;
+			break;
+		}
 		pos++;
 	}
-	return -1;
+	g_list_free (children);
+
+	if (!found)
+		return -1;
+	else
+		return pos;
 }
 
 
@@ -667,7 +700,26 @@ new_launcher_dialog_response_cb (GtkWidget *dialog,
 	pos = GPOINTER_TO_INT (ppos);
 
 	if (response == GTK_RESPONSE_HELP) {
-		/* FIXME */
+		GError *error = NULL;
+
+		gnome_help_display_desktop_on_screen (NULL,
+						      "user-guide",
+						      "user-guide.xml",
+						      "gospanel-52",
+						      gtk_window_get_screen (GTK_WINDOW (dialog)),
+						      &error);
+
+		if (error) {
+			GtkWidget *message_dialog;
+			message_dialog = gtk_message_dialog_new (NULL, 0,
+								 GTK_MESSAGE_ERROR,
+								 GTK_BUTTONS_OK,
+								 _("There was an error displaying help: %s"),
+								 error->message);
+			g_error_free (error);
+			gtk_dialog_run (GTK_DIALOG (message_dialog));
+			gtk_widget_destroy (message_dialog);
+		}
 		
 	} else if (response == GTK_RESPONSE_OK) { 
 		GnomeDesktopItem *ditem;
@@ -721,7 +773,7 @@ quick_lounge_new_launcher (QuickLounge *quick_lounge,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
-	gnome_window_icon_set_from_file (GTK_WINDOW (widget), GNOME_ICONDIR "quick-lounge-applet.png");
+	gtk_window_set_icon_name (GTK_WINDOW (widget), "quick-lounge-applet");
 	gtk_window_set_screen (GTK_WINDOW (widget), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
 	
 	dialog = GTK_DIALOG (widget);
@@ -802,8 +854,24 @@ add_space_cb (GtkWidget *button)
 
 
 static void
-activate_item_cb (GtkWidget *item,
-		  GtkWidget *button)
+execute_item_activate_cb (GtkWidget *item,
+			  GtkWidget *button)
+{
+	QuickBox    *quick_box;
+	QuickLounge *quick_lounge;
+
+	quick_box = (QuickBox*) button->parent;
+	quick_lounge = g_object_get_data (G_OBJECT (quick_box), "quick_lounge");
+	if (quick_lounge == NULL)
+		return;
+
+	gtk_button_clicked (GTK_BUTTON (button));
+}
+
+
+static void
+properties_activate_cb (GtkWidget *item,
+			GtkWidget *button)
 {
 	QuickBox    *quick_box;
 	QuickLounge *quick_lounge;
@@ -824,15 +892,21 @@ populate_context_menu (GtkWidget *popup_menu,
 {
 	GtkWidget *item;
 
-	if (! QUICK_IS_SEPARATOR (button)) {
-		item = gtk_image_menu_item_new_with_mnemonic (_("_Properties"));
-		gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU));
+	if (! QUICK_IS_SEPARATOR (button)) {		
+		item = gtk_image_menu_item_new_from_stock (GTK_STOCK_EXECUTE, NULL);
 		gtk_widget_show_all (item);
-	
+		gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
 		g_signal_connect (G_OBJECT (item), 
 				  "activate",
-				  G_CALLBACK (activate_item_cb), 
+				  G_CALLBACK (execute_item_activate_cb), 
+				  button);
+
+		item = gtk_image_menu_item_new_from_stock (GTK_STOCK_PROPERTIES, NULL);
+		gtk_widget_show_all (item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
+		g_signal_connect (G_OBJECT (item), 
+				  "activate",
+				  G_CALLBACK (properties_activate_cb), 
 				  button);
 
 		/**/
@@ -886,11 +960,9 @@ populate_context_menu (GtkWidget *popup_menu,
 
 	/**/
 
-	item = gtk_image_menu_item_new_with_mnemonic (_("_Remove"));
-	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU));
+	item = gtk_image_menu_item_new_from_stock (GTK_STOCK_REMOVE, NULL);
 	gtk_widget_show_all (item);
-
+	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
 	g_signal_connect_swapped (G_OBJECT (item), 
 				  "activate",
 				  G_CALLBACK (item_remove_cb), 
@@ -917,19 +989,20 @@ static GtkWidget *
 get_button_from_uri (QuickBox   *quick_box,
 		     const char *uri1)
 {
-	GtkBox *box = GTK_BOX (quick_box);
-	GList  *scan;
+	GList  *children, *scan;
 
-	for (scan = box->children; scan; scan = scan->next) {
-		GtkBoxChild *child = scan->data;
-		const char  *uri2;
+	children = gtk_container_get_children (GTK_CONTAINER (quick_box));
+	for (scan = children; scan; scan = scan->next) {
+		GtkWidget  *child_widget = scan->data;
+		const char *uri2;
 
-		uri2 = g_object_get_data (G_OBJECT (child->widget), "uri");
+		uri2 = g_object_get_data (G_OBJECT (child_widget), "uri");
 		if (uri2 == NULL)
 			continue;
 		if (strcmp (uri1, uri2) == 0)
-			return child->widget;
+			return child_widget;
 	}
+	g_list_free (children);
 
 	return NULL;
 }
@@ -1008,30 +1081,31 @@ drag_data_received  (GtkWidget          *widget,
 void
 quick_lounge_save_order (QuickLounge *quick_lounge)
 {
-	GtkBox       *box = GTK_BOX (quick_lounge->quick_box);
 	PanelApplet  *applet = PANEL_APPLET (quick_lounge->applet);
 	GConfClient  *client;
 	char         *full_key;
-	GList        *scan;
+	GList        *children, *scan;
 	GSList       *uri_list = NULL;
-
-	for (scan = box->children; scan; scan = scan->next) {
-		GtkBoxChild      *child_info = scan->data;
-		GtkWidget        *button = child_info->widget;
+	
+	children = gtk_container_get_children (GTK_CONTAINER (quick_lounge->quick_box));
+	for (scan = children; scan; scan = scan->next) {
+		GtkWidget        *child_widget = scan->data;
 		GnomeDesktopItem *ditem;
 		
-		if (QUICK_IS_SEPARATOR (button)) {
+		if (QUICK_IS_SEPARATOR (child_widget)) {
 			uri_list = g_slist_prepend (uri_list, g_strdup (""));
 			continue;
 		}
 
-		ditem = g_object_get_data (G_OBJECT (button), "ditem");
+		ditem = g_object_get_data (G_OBJECT (child_widget), "ditem");
 		if (ditem != NULL) {
 			const char *uri;
 			uri = file_name_from_path (gnome_desktop_item_get_location (ditem));
 			uri_list = g_slist_prepend (uri_list, g_strdup (uri));
 		}
 	}
+	g_list_free (children);
+
 	uri_list = g_slist_reverse (uri_list);
 
 	full_key = panel_applet_gconf_get_full_key (applet, PREFS_ORDER);
@@ -1173,8 +1247,7 @@ quick_lounge_load_uri_async (QuickLounge  *quick_lounge,
 			     const char   *uri)
 {
 	QuickBox     *quick_box = quick_lounge->quick_box;
-	GList        *children;
-	GtkContainer *container;
+	GList        *children, *scan;
 
 	if (quick_lounge->location != uri) {
 		g_free (quick_lounge->location);
@@ -1186,12 +1259,12 @@ quick_lounge_load_uri_async (QuickLounge  *quick_lounge,
 		path_list_handle_free (quick_lounge->handle);
 	}
 
-	container = GTK_CONTAINER (quick_box);
-	for (children = GTK_BOX (quick_box)->children; children; ) {
-		GtkBoxChild *child = children->data;
-		gtk_container_remove (container, child->widget);
-		children = GTK_BOX (quick_box)->children;
+	children = gtk_container_get_children (GTK_CONTAINER (quick_box));
+	for (scan = children; scan; scan = scan->next) {
+		GtkWidget *child_widget = scan->data;
+		gtk_widget_destroy (child_widget);
 	}
+	g_list_free (children);
 
 	quick_lounge->handle = path_list_async_new (quick_lounge->location,
 						    load_uri__step2,
@@ -1203,24 +1276,23 @@ void
 quick_lounge_load_uri_sync (QuickLounge  *quick_lounge, 
 			    const char   *uri)
 {
-	GtkContainer *container;
-	GList        *children;
+	GList        *children = NULL, *scan;
 	QuickBox     *quick_box = quick_lounge->quick_box;
 	GList        *file_list = NULL, *dir_list = NULL;
 	GList        *order_list = NULL;
-	GList        *files, *scan;
+	GList        *files;
 
 	if (quick_lounge->location != uri) {
 		g_free (quick_lounge->location);
 		quick_lounge->location = g_strdup (uri);
 	}
 
-	container = GTK_CONTAINER (quick_box);
-	for (children = GTK_BOX (quick_box)->children; children; ) {
-		GtkBoxChild *child = children->data;
-		gtk_container_remove (container, child->widget);
-		children = GTK_BOX (quick_box)->children;
+	children = gtk_container_get_children (GTK_CONTAINER (quick_box));
+	for (scan = children; scan; scan = scan->next) {
+		GtkWidget *child_widget = scan->data;
+		gtk_widget_destroy (child_widget);
 	}
+	g_list_free (children);
 
 	if (! path_list_new (quick_lounge->location, &file_list, &dir_list))
 		return;
@@ -1394,9 +1466,6 @@ copy_default_items_to_uri (const char *to_uri)
 }
 
 
-
-
-
 static gboolean
 applet_button_press_cb (GtkWidget         *widget,
 			GdkEventButton    *event)
@@ -1405,14 +1474,6 @@ applet_button_press_cb (GtkWidget         *widget,
 }
 
 
-static void
-icon_theme_changed (GnomeIconTheme *icon_theme,
-		    QuickLounge    *quick_lounge)
-{
-	quick_lounge_load_uri (quick_lounge, quick_lounge->location);
-}
-
-
 static gboolean
 quick_lounge_applet_fill (PanelApplet *applet)
 {
@@ -1422,6 +1483,8 @@ quick_lounge_applet_fill (PanelApplet *applet)
 	int          min_cols, max_size;
 	gboolean     icon_size_follows_panel;
 
+	gtk_window_set_default_icon_name ("quick-lounge-applet");
+
 	quick_lounge = g_new0 (QuickLounge, 1);
 
 	quick_lounge->applet = GTK_WIDGET (applet);
@@ -1433,13 +1496,7 @@ quick_lounge_applet_fill (PanelApplet *applet)
 							  g_free, 
 							  NULL);
 
-	quick_lounge->icon_theme = gnome_icon_theme_new ();
-	gnome_icon_theme_set_allow_svg (GNOME_ICON_THEME (quick_lounge->icon_theme), TRUE);
-	gnome_icon_theme_append_search_path (quick_lounge->icon_theme, PIXMAPSDIR);
-	g_signal_connect (G_OBJECT (quick_lounge->icon_theme),
-			  "changed",
-			  G_CALLBACK (icon_theme_changed),
-			  quick_lounge);
+	quick_lounge->icon_theme = gtk_icon_theme_get_default ();
 
 	/**/
 
@@ -1484,7 +1541,7 @@ quick_lounge_applet_fill (PanelApplet *applet)
 
 	gtk_drag_dest_set (GTK_WIDGET (quick_lounge->quick_box),
                            GTK_DEST_DEFAULT_ALL,
-                           target_table, n_targets,
+                           target_table, G_N_ELEMENTS (target_table),
 			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
 	
 	g_signal_connect (G_OBJECT (quick_lounge->quick_box), 
